pub struct GetDataCatalogFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to GetDataCatalog.
Returns the specified data catalog.
Implementations
Sourceimpl GetDataCatalogFluentBuilder
impl GetDataCatalogFluentBuilder
Sourcepub fn as_input(&self) -> &GetDataCatalogInputBuilder
pub fn as_input(&self) -> &GetDataCatalogInputBuilder
Access the GetDataCatalog as a reference.
Sourcepub async fn send(
self,
) -> Result<GetDataCatalogOutput, SdkError<GetDataCatalogError, HttpResponse>>
pub async fn send( self, ) -> Result<GetDataCatalogOutput, SdkError<GetDataCatalogError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<GetDataCatalogOutput, GetDataCatalogError, Self>
pub fn customize( self, ) -> CustomizableOperation<GetDataCatalogOutput, GetDataCatalogError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn work_group(self, input: impl Into<String>) -> Self
pub fn work_group(self, input: impl Into<String>) -> Self
The name of the workgroup. Required if making an IAM Identity Center request.
Sourcepub fn set_work_group(self, input: Option<String>) -> Self
pub fn set_work_group(self, input: Option<String>) -> Self
The name of the workgroup. Required if making an IAM Identity Center request.
Sourcepub fn get_work_group(&self) -> &Option<String>
pub fn get_work_group(&self) -> &Option<String>
The name of the workgroup. Required if making an IAM Identity Center request.